BaseBleScanner class abstract

Inheritance

Constructors

BaseBleScanner()

Properties

devices → List<BlePeripheral>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → BleScannerState
no setterinherited
stateStream → Stream<BleScannerState>
no setterinherited

Methods

addPeripheral(BlePeripheral device) → void
canNotifyState() → bool
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyState(BleScannerState state) → void
inherited
scan() → Future<void>
inherited
stop() → Future<void>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited