BleScanner class abstract

Inheritance
Implementers

Constructors

BleScanner()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → BleScannerState
no setterinherited
stateStream → Stream<BleScannerState>
no setterinherited

Methods

canNotifyState() → bool
inherited
dispose() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyState(BleScannerState state) → void
inherited
scan() → Future<void>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited