BleSerial class

Inheritance

Constructors

BleSerial({required BleCharacteristic characteristicRx, required BleCharacteristic characteristicTx})

Properties

dataStream → Stream<Uint8List>
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canNotifyData() → bool
inherited
dispose() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyData(Uint8List data) → void
inherited
send({required Uint8List data}) → Future<void>
startNotifications() → Future<void>
stopNotifications() → Future<void>
toString() → String
A string representation of this object.
inherited
waitData({required void timeoutCallback(), Duration duration = const Duration(seconds: 20)}) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited